/*
 * Copyright 2010 Joachim Ansorg, mail@ansorg-it.com
 * File: TernaryExpression.java, Class: TernaryExpression
 * Last modified: 2010-04-17
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.ansorgit.plugins.bash.lang.parser.arithmetic;

import com.ansorgit.plugins.bash.lang.parser.BashPsiBuilder;
import com.ansorgit.plugins.bash.lang.parser.util.ParserUtil;
import com.intellij.lang.PsiBuilder;

/**
 * Parsing of ternary arithmetic expressions.
 * <p/>
 * User: jansorg
 * Date: Feb 6, 2010
 * Time: 4:29:05 PM
 */
class TernaryExpression implements ArithmeticParsingFunction {
    private ArithmeticParsingFunction logicalOr = ParenExpr.delegate(new LogicalOr());

    public boolean isValid(BashPsiBuilder builder) {
        return logicalOr.isValid(builder);
    }

    public boolean parse(BashPsiBuilder builder) {
        PsiBuilder.Marker marker = builder.mark();
        boolean ok = logicalOr.parse(builder);

        if (ok && ParserUtil.conditionalRead(builder, ARITH_QMARK)) {
            ok = logicalOr.parse(builder);//check this
            ok = ok && ParserUtil.conditionalRead(builder, ARITH_COLON) && logicalOr.parse(builder);

            if (ok) {
                marker.done(ARITH_TERNERAY_ELEMENT);
            } else {
                marker.drop();
            }
        } else {
            marker.drop();
        }

        return ok;
    }

    public boolean partialParsing(BashPsiBuilder builder) {
        return logicalOr.partialParsing(builder);
    }

    public boolean isValidPartial(BashPsiBuilder builder) {
        return logicalOr.isValidPartial(builder);
    }
}